@@ -548,6 +548,10 @@ POPPLER_PUBLIC
 void poppler_annot_ink_set_ink_list(PopplerAnnotInk *annot, PopplerPath **ink_list, gsize n_paths);
 POPPLER_PUBLIC
 PopplerPath **poppler_annot_ink_get_ink_list(PopplerAnnotInk *annot, gsize *n_paths);
+POPPLER_PUBLIC
+void poppler_annot_ink_set_draw_below(PopplerAnnotInk *annot, gboolean draw_below);
+POPPLER_PUBLIC
+gboolean poppler_annot_ink_get_draw_below(PopplerAnnotInk *annot);
 
 G_END_DECLS
 
